python3-krakenex release news
=============================

0.1.3 - Tue Jan 31 2017
-----------------------
* Single-source version and URL - used during setup and in ``User-Agent``.

0.1.2 - Sat Nov 05 2016
-----------------------
* Ship examples with PyPI package.

0.1.1 - Sat Nov 05 2016
-----------------------
* Renamed README and LICENSE according to PyPI recommendations.

0.1.0 - Mon Oct 31 2016
-----------------------
* First PyPI package upload (source distribution).
* Change versioning scheme to semantic versioning (recommended by PyPI).

0.0.6.2 - Mon Apr 18 2016
-------------------------
* Basic documentation with sphinx.

0.0.6.1 - Fri Mar 25 2016
-------------------------
* Classes sub-classed from ``object``.

0.0.6 - Tue Jul 22 2014
-----------------------
* Core license changed to LGPLv3. Examples remain at Simplified BSD.

0.0.5 - Thu May 1 2014
----------------------
* ``API.set_connection()`` method to set default connection.

0.0.4.1 - Wed Apr 30 2014
-------------------------
* Fixed ``User-Agent`` still reporting version ``0.0.3``.

0.0.4 - Fri Apr 11 2014
-----------------------
* Original Python 2 version ported to Python 3.
* ``conditional-close`` example.
* Examples licensed under the Simplified BSD license.

0.0.3 - Fri Jan 10 2014
-----------------------
* ``API.load_key()`` method to allow loading key/secret pair from file.

0.0.2 - Sat Jan 4 2014
-----------------------
* Basic implementation of ``KrakenConnection`` class.
* Optional ``conn`` argument to query methods allows connection reuse.

0.0.1 - Wed Dec 11 2013
-----------------------
* Basic ``API`` class with ``query_{public,private}()`` methods.
* Licensed under GPLv3.
